package v1

import (
	"dy-admin/internal/pcmserver/bus/model"
	"dy-admin/internal/pcmserver/bus/model/response"
	"dy-admin/pkg/bind"
	"dy-admin/pkg/rescode"
	"github.com/gin-gonic/gin"
	"github.com/gin-gonic/gin/binding"
)

type BusConfigApi struct {
}

// UpdateBusConfig
// @Tags      配置管理
// @Summary   更新配置
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body     model.CabinetConfig true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/config [put]
func (s *BusConfigApi) UpdateBusConfig(c *gin.Context) {
	var config model.CabinetConfig
	if err := bind.Bind(c, &config, binding.JSON); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	err := BusConfigService.UpdateConfig(&config)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	rescode.WriteSuccessResponse(c, nil)
}

// GetBusConfig
// @Tags      配置管理
// @Summary   获取配置
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/config [get]
func (s *BusConfigApi) GetBusConfig(c *gin.Context) {

	res, err := BusConfigService.GetBusConfig()
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	rescode.WriteSuccessResponse(c, response.ConfigResponse{Config: res})
	return
}
