package v1

import (
	"dy-admin/internal/pcmserver/bus/model/request"
	"dy-admin/internal/pcmserver/common"
	"dy-admin/pkg/bind"
	"dy-admin/pkg/rescode"
	"github.com/gin-gonic/gin"
	"github.com/gin-gonic/gin/binding"
)

type ConnectLogApi struct {
}

// DeleteConnectLog
// @Tags      连接日志管理
// @Summary   批量删除连接日志
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body    request.DeleteCronLogReq true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/connect [delete]
func (api *ConnectLogApi) DeleteConnectLog(c *gin.Context) {
	var req request.DeleteConnectLogReq
	if err := bind.Bind(c, &req, binding.Query); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	err := ConnectService.DeleteConnectLog(req)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}
	rescode.WriteSuccessResponse(c, nil)
	return
}

// GetConnectLogList
// @Tags      连接日志管理
// @Summary   分页获取连接日志
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body    request.ConnectLogSearch true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/connect/list [get]
func (api *ConnectLogApi) GetConnectLogList(c *gin.Context) {
	var pageInfo request.ConnectLogSearch
	if err := bind.Bind(c, &pageInfo, binding.Query); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	list, total, err := ConnectService.GetConnectLogList(pageInfo)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	rescode.WriteSuccessResponse(c, common.PageResult{
		List:     list,
		Total:    total,
		Page:     pageInfo.Page,
		PageSize: pageInfo.PageSize,
	})
	return
}
