package v1

import (
	"dy-admin/internal/pcmserver/bus/model/request"
	"dy-admin/internal/pcmserver/bus/model/response"
	"dy-admin/internal/pcmserver/common"
	"dy-admin/internal/pcmserver/pkg/code"
	"dy-admin/internal/pcmserver/utils"
	"dy-admin/pkg/bind"
	"dy-admin/pkg/rescode"
	"github.com/gin-gonic/gin"
	"github.com/gin-gonic/gin/binding"
)

type GridApi struct {
}

// GetCabinetGrids
// @Tags      格子管理
// @Summary   获取柜子的格子
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body     request.GridSearch true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/grid/list [get]
func (ga *GridApi) GetCabinetGrids(c *gin.Context) {
	var req request.GridSearch
	if err := bind.Bind(c, &req, binding.Query); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}

	err := utils.Verify(req, utils.GetGridsVerify)
	if err != nil {
		err = rescode.RegisterErrorWithMessage(err, err.Error(), code.ErrCodeMap[code.ErrValidationCode])
		rescode.WriteErrResponse(c, err)
		return
	}

	list, err := gridService.GetGridListByCabinetID(req.CabinetID)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}
	var use int
	for _, grid := range list {
		if grid.Staff.ID != 0 {
			use++
		}
	}

	rescode.WriteSuccessResponse(c, response.GridListResponse{
		List:  list,
		Use:   use,
		Total: len(list),
	})
	return
}

// OpenGrid
// @Tags      格子管理
// @Summary   开启格子
// @Security  ApiKeyAuth
// @accept    application/json
// @Produce   application/json
// @Param     data  body     common.IdReq true  "参数"
// @Success   200   {object}  rescode.ErrCode
// @Router    /bus/v1/grid/open [post]
func (ga *GridApi) OpenGrid(c *gin.Context) {
	var ID common.IdReq
	if err := bind.Bind(c, &ID, binding.JSON); err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}
	err := utils.Verify(ID, utils.IdsVerify)
	if err != nil {
		err = rescode.RegisterErrorWithMessage(err, err.Error(), code.ErrCodeMap[code.ErrValidationCode])
		rescode.WriteErrResponse(c, err)
		return
	}

	err = gridService.OpenGrid(ID.ID)
	if err != nil {
		rescode.WriteErrResponse(c, err)
		return
	}
	rescode.WriteSuccessResponse(c, nil)
	return
}
