package cabinet_pkg

import (
	"dy-admin/internal/pcmserver/bus/model"
	"dy-admin/internal/pcmserver/common"
	"dy-admin/internal/pcmserver/global"
	"encoding/json"
	"gorm.io/gorm"
	"gorm.io/gorm/clause"
	"sync"
)

type CabinetConfig struct {
	lock sync.Mutex
	*model.CabinetConfig
}

var cabinetMemConfig *CabinetConfig

func InitCabinetMemConfig() {
	cabinetMemConfig = new(CabinetConfig)
	var busConfig model.BusConfig

	if err := global.DB.Model(&model.BusConfig{}).First(&busConfig).Error; err != nil {
		if err == gorm.ErrRecordNotFound {
			// 创建一个新的
			cabinetConfig := model.CabinetConfig{
				ID:          1,
				ManageModel: 2, // 1-强制模式 2-人性化模式
			}
			config, _ := json.Marshal(cabinetConfig)
			entities := model.BusConfig{
				Model:  common.Model{ID: cabinetConfig.ID},
				Config: string(config),
			}
			if err := global.DB.Clauses(clause.OnConflict{UpdateAll: true}).Create(&entities).Error; err != nil {
				panic(err)
			}
		} else {
			panic(err)
		}
	}
	config := new(model.CabinetConfig)
	err := json.Unmarshal([]byte(busConfig.Config), config)
	if err != nil {
		panic(err)
	}
	cabinetMemConfig.CabinetConfig = config
}

func SetCabinetMemConfig(config *model.CabinetConfig) {
	cabinetMemConfig.lock.Lock()
	defer cabinetMemConfig.lock.Unlock()
	cabinetMemConfig.CabinetConfig = config
}

// IsHumanization 是否人性化管理
func IsHumanization() bool {
	cabinetMemConfig.lock.Lock()
	defer cabinetMemConfig.lock.Unlock()
	switch cabinetMemConfig.CabinetConfig.ManageModel {
	case 2:
		return true
	default:
		return false
	}
}

func GetMemConfig() *CabinetConfig {
	cabinetMemConfig.lock.Lock()
	defer cabinetMemConfig.lock.Unlock()
	return cabinetMemConfig
}
