package dataProto

const (
	PkgLengthCabinetConfig    = 0x09 // 配置柜子编号包长度
	PkgLengthDoorControl      = 0x07 // 配置控制门包长度
	PkgLengthOpenGrid         = 0x09 // 开箱门包长度
	PkgLengthGridLockStatus   = 0x0C // 锁状态反馈长度
	PkgLengthGetCabinetReq    = 0x07 // 获取柜子状态请求长度
	PkgLengthGetCabinetRes    = 0x0E // 获取柜子状态响应长度
	PkgLengthGetDoorStatusReq = 0x07 // 下位机查询柜子当前是否允许开包长度
	PkgLengthGridControl      = 0x09 // 配置控制单个格子包长度
)

const (
	StartSymbolCabinetConfig              = 0x4A // 配置柜子编号数据包开始符号
	StartSymbolCabinetConfigRes           = 0x47 // 配置柜子编号响应数据包开始符号
	StartSymbolDoorControl                = 0x4B // 配置允许/禁止打开箱门数据包开始符号
	StartSymbolDoorControlRes             = 0x4C // 配置允许/禁止打开箱门数据包响应符号
	StartSymbolOpenGrid                   = 0xEA // 开箱门开始标志
	StartSymbolGridLockStatusOrGridStatus = 0x5A // 锁状态响应数据包开始符号或者是获取柜子所有信息的响应开始符号
	StartSymbolGetCabinetReq              = 0x9A // 获取柜子状态请求开始符号
	StartSymbolGetDoorStatusReq           = 0x4E // 下位机查询柜子当前是否允许开
	StartSymbolGridControl                = 0x2B //配置允许/禁止打开格子符号
	StartSymbolGridControlRes             = 0x2C //配置允许/禁止打开格子响应符号
	StartSymbolPing                       = 0xB3
	StartSymbolPong                       = 0x5D
)

const (
	CmdCabinetConfig      = 0x7A // 配置柜子编号命令
	CmdDoorControlEnable  = 0x37 // 允许开门命令
	CmdDoorControlDisable = 0x39 // 禁止开门命令
	CmdOpenGrid           = 0xD1 // 开箱门命令
	CmdGridLockStatus     = 0xA2 // 锁状态反馈命令
	CmdGetCabinetReq      = 0x91 // 获取柜子状态命令
	CmdGetCabinetRes      = 0xA3 // 获取柜子状态响应命令
	CmdGetDoorStatusReq   = 0x4C // 下位机查询柜子当前是否允许开
	CmdGridControlEnable  = 0x01 //允许格子开门
	CmdGridControlDisable = 0x00 //禁止格子开门
)

const (
	OpenGridLockOpen   = 0x00
	OpenGridLockBroken = 0x02
)

const (
	PingHex = "07B33BC44CD55D"
	PongHex = "075DD54CC43BB3"
)

// CabinetConfigProto 配置柜子编号请求
type CabinetConfigProto struct {
	PkgLength        uint8  // 包长度
	StartSymbol      uint8  // 开始标志
	Cmd              uint8  // 命令
	CabinetNumber    uint16 // 柜子编号
	CabinetGridCount uint16 // 柜子箱门总数
	CRCCode          uint16 // CRC校验码
}

// DoorControlProto 门控制协议 允许开 禁止开
type DoorControlProto struct {
	PkgLength     uint8  // 包长度
	StartSymbol   uint8  // 开始标志
	CabinetNumber uint16 // 柜子编号
	Cmd           uint8  // 命令
	CRCCode       uint16 // CRC校验码
}

// OpenGridProto 开门
type OpenGridProto struct {
	PkgLength     uint8  // 包长度
	StartSymbol   uint8  // 开始标志
	Cmd           uint8  // 命令
	CabinetNumber uint16 // 柜子编号
	GridNumber    uint16 // 箱门编号
	CRCCode       uint16 // CRC校验码
}

// GridLockStatusProto 箱门锁状态 开箱门时返回
type GridLockStatusProto struct {
	PkgLength        uint8  // 包长度
	StartSymbol      uint8  // 开始标志
	Cmd              uint8  // 命令
	CabinetNumber    uint16 // 柜子编号
	CabinetGridCount uint16 // 柜子箱门总数
	GridNumber       uint16 // 箱门编号
	LockStatus       uint8  // 锁的状态
	CRCCode          uint16 // CRC校验码
}

// GetCabinetReq 查询柜子的所有信息
type GetCabinetReq struct {
	PkgLength     uint8  // 包长度
	StartSymbol   uint8  // 开始标志
	Cmd           uint8  // 命令
	CabinetNumber uint16 // 柜子编号
	CRCCode       uint16 // CRC校验码
}

// GridStatsProto 获取柜子信息请求
type GridStatsProto struct {
	PkgLength   uint8  // 包长度
	StartSymbol uint8  // 开始标志
	Cmd         uint8  // 命令
	GridNumber  uint16 // 箱门编号
	RFID        uint32 // RFID编号
	LockStatus  uint8  // 锁状态 0-箱门打开 1-箱门关闭 2-锁故障
	StoreStatus uint8  // 存物状态 0-未存物 1-存物 2-物品未登记
	CellStatus  uint8  // 电池状态 0-未充电 1-正充电 2-充满电
	CRCCode     uint16 // CRC校验码
}

// GetDoorStatusReq 获取柜子锁状态请求
// 响应使用 DoorControlProto
type GetDoorStatusReq struct {
	PkgLength     uint8  // 包长度
	StartSymbol   uint8  // 开始标志
	Cmd           uint8  // 命令
	CabinetNumber uint16 // 箱门编号
	CRCCode       uint16 // CRC校验码
}

// CabinetConnect 柜子连接信息回传结构
type CabinetConnect struct {
	IsConnected bool
}

type GridControlProto struct {
	PkgLength     uint8  // 包长度
	StartSymbol   uint8  // 开始标志
	CabinetNumber uint16 // 柜子编号
	GridNumber    uint16 // 箱门编号
	Cmd           uint8  // 命令
	CRCCode       uint16 // CRC校验码
}
