package dataProto

import "fmt"

// Package 解决半包和粘包问题结构
type Package struct {
	Message  []byte
	PackChan chan []byte
}

func (p *Package) NewPacket(data []byte) error {
	if data == nil || len(data) == 0 {
		return fmt.Errorf("packet data is nil")
	}
	p.Message = append(p.Message, data...)

	var pkgLen byte
	j := 0
	for j = 0; j < len(p.Message); j++ {
		pkgLen = p.Message[j]
		if pkgLen != 0 {
			break
		}
	}

	if pkgLen == 0 {
		p.Message = p.Message[0:0]
		return nil
	} else {
		p.Message = p.Message[j:]
	}

	for len(p.Message) >= int(pkgLen) {
		pack := p.Message[:int(pkgLen)]
		p.PackChan <- pack
		p.Message = p.Message[int(pkgLen):]

		if len(p.Message) == 0 {
			return nil
		}

		i := 0
		for i = 0; i < len(p.Message); i++ {
			pkgLen = p.Message[i]
			if pkgLen != 0 {
				break
			}
		}
		// 最后依然为0,说明整个字节数组都为0.直接清楚
		if pkgLen == 0 {
			p.Message = p.Message[0:0]
			return nil
		} else {
			p.Message = p.Message[i:]
		}

	}

	return nil
}

func (p *Package) DestroyPacket() {
	p.Message = nil
	close(p.PackChan)
}
