package service

import (
	"dy-admin/internal/pcmserver/bus/cabinet_pkg"
	"dy-admin/internal/pcmserver/bus/model"
	"dy-admin/internal/pcmserver/common"
	"dy-admin/internal/pcmserver/global"
	"dy-admin/internal/pcmserver/pkg/code"
	"dy-admin/pkg/log"
	"dy-admin/pkg/rescode"
	"encoding/json"
)

type BusConfigService struct {
}

func (s *BusConfigService) GetBusConfig() (config *model.CabinetConfig, err error) {

	var busConfig model.BusConfig

	if err = global.DB.Model(&model.BusConfig{}).First(&busConfig).Error; err != nil {
		return config, rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode])
	}
	config = new(model.CabinetConfig)
	err = json.Unmarshal([]byte(busConfig.Config), config)

	if err != nil {
		return config, rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDecodingFailedCode])
	}

	return
}

func (s *BusConfigService) UpdateConfig(cabinetConfig *model.CabinetConfig) (err error) {
	cabs := cabinet_pkg.GetCabinets()
	if cabinetConfig.ManageModel == 1 {
		// 如果切换为强制管理，需要根据当前柜子的状态，分别下发禁止开还是允许开
		for _, cab := range cabs {
			if cab.IsAllowOpen {
				err = cabinet_pkg.EnableOpenDoor(cab.CabinetID, true)
				if err != nil {
					log.Error(err.Error())
				}
			} else {
				err = cabinet_pkg.DisableOpenDoor(cab.CabinetID)
				if err != nil {
					log.Error(err.Error())
				}
			}
		}

	} else if cabinetConfig.ManageModel == 2 {
		// 如果切换为人性化管理，无论柜子当前平台状态是什么，全部下发允许开指令
		for _, cab := range cabs {
			err = cabinet_pkg.EnableOpenDoor(cab.CabinetID, false)
			if err != nil {
				log.Error(err.Error())
			}
		}
	}

	config, err := json.Marshal(cabinetConfig)
	if err != nil {
		return rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrEncodingFailedCode])
	}
	busConfig := &model.BusConfig{
		Model:  common.Model{ID: cabinetConfig.ID},
		Config: string(config),
	}

	err = global.DB.Updates(busConfig).Error
	if err != nil {
		return rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode])
	}

	cabinet_pkg.SetCabinetMemConfig(cabinetConfig)

	return nil
}
