package code

import "dy-admin/pkg/rescode"

// 错误码设计
// 服务名  模块名  错误码序号
// 10     01     01
// 每个服务下的每个模块可以注册100个错误
// 000000 成功
// 990000 系统错误编码使用范围
// 服务名可用范围 01-98

var (
	ErrCodeMap = map[int]*rescode.ErrCode{
		// base
		ErrBindCode:              rescode.NewErrCode(rescode.HttpCode400, ErrBindCode, "解析参数错误", ""),
		ErrValidationCode:        rescode.NewErrCode(rescode.HttpCode400, ErrValidationCode, "参数验证错误", ""),
		ErrTokenInvalidCode:      rescode.NewErrCode(rescode.HttpCode401, ErrTokenInvalidCode, "token无效", ""),
		ErrPageNotFoundCode:      rescode.NewErrCode(rescode.HttpCode404, ErrPageNotFoundCode, "页面未找到", ""),
		ErrDatabaseCode:          rescode.NewErrCode(rescode.HttpCode500, ErrDatabaseCode, "数据库错误", ""),
		ErrIllegalOrderFieldCode: rescode.NewErrCode(rescode.HttpCode500, ErrIllegalOrderFieldCode, "无效排序字段", ""),
		ErrTokenExpiredCode:      rescode.NewErrCode(rescode.HttpCode401, ErrTokenExpiredCode, "token已过期", ""),
		ErrInvalidAuthHeaderCode: rescode.NewErrCode(rescode.HttpCode401, ErrInvalidAuthHeaderCode, "无效的授权header", ""),
		ErrMissingHeaderCode:     rescode.NewErrCode(rescode.HttpCode401, ErrMissingHeaderCode, "header中Authorization为空", ""),
		ErrPasswordIncorrectCode: rescode.NewErrCode(rescode.HttpCode401, ErrPasswordIncorrectCode, "密码不正确", ""),
		ErrPermissionDeniedCode:  rescode.NewErrCode(rescode.HttpCode403, ErrPermissionDeniedCode, "无此权限", ""),
		ErrJwtInstanceCode:       rescode.NewErrCode(rescode.HttpCode500, ErrJwtInstanceCode, "jwt实例问未初始化", ""),
		ErrDataPermissionCode:    rescode.NewErrCode(rescode.HttpCode403, ErrDataPermissionCode, "不支持的数据权限", ""),
		ErrEncodingFailedCode:    rescode.NewErrCode(rescode.HttpCode500, ErrEncodingFailedCode, "数据encoding失败", ""),
		ErrDecodingFailedCode:    rescode.NewErrCode(rescode.HttpCode500, ErrDecodingFailedCode, "数据decoding失败", ""),
		ErrInvalidJSONCode:       rescode.NewErrCode(rescode.HttpCode500, ErrInvalidJSONCode, "无效的json", ""),
		ErrEncodingJSONCode:      rescode.NewErrCode(rescode.HttpCode500, ErrEncodingJSONCode, "json编码失败", ""),
		ErrDecodingJSONCode:      rescode.NewErrCode(rescode.HttpCode500, ErrDecodingJSONCode, "json解码失败", ""),
		ErrWSConnectCode:         rescode.NewErrCode(rescode.HttpCode500, ErrWSConnectCode, "连接失败", ""),
		// sys
		ErrCasbinInternalCode:   rescode.NewErrCode(rescode.HttpCode500, ErrCasbinInternalCode, "casbin内部错误", ""),
		ErrApiAlreadyExistCode:  rescode.NewErrCode(rescode.HttpCode500, ErrApiAlreadyExistCode, "当前api已存在", ""),
		ErrApiNotFoundCode:      rescode.NewErrCode(rescode.HttpCode500, ErrApiNotFoundCode, "当前api不存在", ""),
		ErrDeleteMenuUseCode:    rescode.NewErrCode(rescode.HttpCode500, ErrDeleteMenuUseCode, "api被菜单引用，不能删除", ""),
		ErrMenuAlreadyExistCode: rescode.NewErrCode(rescode.HttpCode500, ErrMenuAlreadyExistCode, "菜单已经存在", ""),
		ErrParentMenuPathsCode:  rescode.NewErrCode(rescode.HttpCode500, ErrParentMenuPathsCode, "父节点paths异常,尝试更新父节点paths", ""),
		ErrParentHasSonCode:     rescode.NewErrCode(rescode.HttpCode500, ErrParentHasSonCode, "菜单存在子菜单", ""),
		ErrRoleAlreadyExistCode: rescode.NewErrCode(rescode.HttpCode500, ErrRoleAlreadyExistCode, "角色已经存在", ""),
		ErrRoleNotFoundCode:     rescode.NewErrCode(rescode.HttpCode500, ErrRoleNotFoundCode, "角色不存在", ""),
		ErrUserAlreadyExistCode: rescode.NewErrCode(rescode.HttpCode500, ErrUserAlreadyExistCode, "用户已经注册", ""),
		ErrUserNotFoundCode:     rescode.NewErrCode(rescode.HttpCode500, ErrUserNotFoundCode, "用户不存在", ""),
		ErrPasswordCode:         rescode.NewErrCode(rescode.HttpCode500, ErrPasswordCode, "密码错误", ""),
		ErrNotAllowLoginCode:    rescode.NewErrCode(rescode.HttpCode500, ErrNotAllowLoginCode, "用户被禁止登录", ""),
		ErrKillSelfCode:         rescode.NewErrCode(rescode.HttpCode500, ErrKillSelfCode, "不能删除自己", ""),
		ErrDeptAlreadyExistCode: rescode.NewErrCode(rescode.HttpCode500, ErrDeptAlreadyExistCode, "部门已经存在", ""),
		ERRDeptHasSonCode:       rescode.NewErrCode(rescode.HttpCode500, ERRDeptHasSonCode, "当前部门存在子部门,无法删除", ""),
		ErrDeptHasUserCode:      rescode.NewErrCode(rescode.HttpCode500, ERRDeptHasSonCode, "当前部门下存在用户,无法删除", ""),
		ErrRoleHasUserCode:      rescode.NewErrCode(rescode.HttpCode500, ErrRoleHasUserCode, "当前角色下存在用户,无法删除", ""),

		// bus
		ErrLeaveParseTimeCode:       rescode.NewErrCode(rescode.HttpCode400, ErrLeaveParseTimeCode, "时间解析错误", ""),
		ErrLeaveStartGTEndCode:      rescode.NewErrCode(rescode.HttpCode400, ErrLeaveStartGTEndCode, "请假时间填写错误,开始时间不能大于结束时间", ""),
		ErrLeaveStartCornTabCode:    rescode.NewErrCode(rescode.HttpCode500, ErrLeaveStartCornTabCode, "请假定时任务启动失败", ""),
		ErrLeaveRemoveCornTabCode:   rescode.NewErrCode(rescode.HttpCode500, ErrLeaveRemoveCornTabCode, "请假定时任务删除失败", ""),
		ErrLeaveDeleteExecutingCode: rescode.NewErrCode(rescode.HttpCode500, ErrLeaveDeleteExecutingCode, "执行中的请假单不能删除", ""),
		ErrLeaveCornTabCode:         rescode.NewErrCode(rescode.HttpCode500, ErrLeaveCornTabCode, "请假定时任务启动失败", ""),
		ErrLeaveRepeatCode:          rescode.NewErrCode(rescode.HttpCode400, ErrLeaveRepeatCode, "该员工有已经提交的请假单,时间冲突", ""),
		ErrStaffGridHasUsedCode:     rescode.NewErrCode(rescode.HttpCode500, ErrStaffGridHasUsedCode, "格子已经被占用", ""),
		ErrCabinetTimeInvalidCode:   rescode.NewErrCode(rescode.HttpCode400, ErrCabinetTimeInvalidCode, "时间格式错误", ""),
		ErrCabinetTimeCornTabCode:   rescode.NewErrCode(rescode.HttpCode500, ErrCabinetTimeCornTabCode, "定时任务启动失败", ""),
		ErrCabinetGridCountCode:     rescode.NewErrCode(rescode.HttpCode500, ErrCabinetGridCountCode, "格子数量只能为12或者44", ""),
		ErrCabinetGridUsedCode:      rescode.NewErrCode(rescode.HttpCode500, ErrCabinetGridUsedCode, "柜子正在被人员使用，无法删除", ""),
		ErrWorkTimeParseTimeCode:    rescode.NewErrCode(rescode.HttpCode400, ErrWorkTimeParseTimeCode, "工作时间解析失败,时间格式为 HH:MM", ""),
		ErrWorkTimeStartGTEndCode:   rescode.NewErrCode(rescode.HttpCode400, ErrWorkTimeStartGTEndCode, "工作时间填写错误,开始时间不能大于结束时间", ""),
		ErrWorkTimeAlreadyExistCode: rescode.NewErrCode(rescode.HttpCode500, ErrWorkTimeAlreadyExistCode, "工作时间已经存在", ""),
		ErrSpecTimeParseTimeCode:    rescode.NewErrCode(rescode.HttpCode400, ErrSpecTimeParseTimeCode, "例外时间解析失败,时间格式为 yyyy-mm-dd HH:MM", ""),
		ErrSpecTimeStartGTEndCode:   rescode.NewErrCode(rescode.HttpCode400, ErrSpecTimeStartGTEndCode, "例外时间填写错误,开始时间不能大于结束时间", ""),
		ErrIPAlreadyExistsCode:      rescode.NewErrCode(rescode.HttpCode400, ErrIPAlreadyExistsCode, "柜子IP已经存在", ""),
		ErrNumberAlreadyExistsCode:  rescode.NewErrCode(rescode.HttpCode400, ErrNumberAlreadyExistsCode, "柜子编号已经存在,不能重复", ""),
		ErrCabinetMemNotFoundCode:   rescode.NewErrCode(rescode.HttpCode500, ErrCabinetMemNotFoundCode, "柜子内存中未找到", ""),
		ErrCabinetNotConnectCode:    rescode.NewErrCode(rescode.HttpCode500, ErrCabinetNotConnectCode, "未与设备连接", ""),
		ErrCabinetDeviceCode:        rescode.NewErrCode(rescode.HttpCode500, ErrCabinetDeviceCode, "与设备交互错误,联系开发者", ""),
		ErrCabinetTimeoutCode:       rescode.NewErrCode(rescode.HttpCode500, ErrCabinetTimeoutCode, "与设备交互超时", ""),
		ErrGridNotFoundCode:         rescode.NewErrCode(rescode.HttpCode500, ErrGridNotFoundCode, "格子不存在", ""),
	}
)
