package resource

import (
	businessModel "dy-admin/internal/pcmserver/bus/model"
	"dy-admin/internal/pcmserver/global"
	"dy-admin/internal/pcmserver/pkg/code"
	"dy-admin/internal/pcmserver/resource/bus"
	"dy-admin/internal/pcmserver/resource/sys"
	systemModel "dy-admin/internal/pcmserver/sys/model"
	systemService "dy-admin/internal/pcmserver/sys/service"
	"dy-admin/pkg/rescode"
	"github.com/gin-gonic/gin"
)

func InitData(c *gin.Context) {

	if err := sys.InitSystemData(); err != nil {
		rescode.WriteErrResponse(c, rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode]))
		return
	}

	if err := bus.InitBusinessData(); err != nil {
		rescode.WriteErrResponse(c, rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode]))
		return
	}

	rescode.WriteSuccessResponse(c, nil)
	return
}

func UpdateData(c *gin.Context) {
	if err := sys.UpdateSystemData(); err != nil {
		rescode.WriteErrResponse(c, rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode]))
		return
	}

	rescode.WriteSuccessResponse(c, nil)
	return
}

func InitDB() {
	// 系统表
	sysModel := []interface{}{&systemModel.Api{}, &systemModel.Dept{}, &systemModel.Menu{}, &systemModel.Role{},
		&systemModel.User{}, &systemModel.OperationRecord{}, &systemModel.LoginLog{}}
	// 业务表
	busModel := []interface{}{&businessModel.Cabinet{}, &businessModel.Grid{}, &businessModel.Staff{}, &businessModel.CabinetTime{},
		&businessModel.WorkTime{}, &businessModel.SpecialTime{}, &businessModel.LeaveLog{}, &businessModel.GridOpenLog{},
		&businessModel.GridStoreLog{}, &businessModel.GridWarnLog{}, &businessModel.DeviceLog{}, &businessModel.CronLog{}, &businessModel.ConnectLog{}, &businessModel.BusConfig{}}
	dst := make([]interface{}, 0)
	dst = append(dst, sysModel...)
	dst = append(dst, busModel...)
	// 建表
	err := global.DB.AutoMigrate(dst...)
	if err != nil {
		panic(err)
	}
	// casbin
	systemService.CasbinServiceInstance.Casbin()
}

// curl localhost:9099/base/initData
