package sys

import (
	"dy-admin/internal/pcmserver/common"
	"dy-admin/internal/pcmserver/pkg/code"
	"dy-admin/internal/pcmserver/sys/model"
	"dy-admin/internal/pcmserver/sys/service"
	"time"
)

func initRoleData() error {
	if err := initAdmin(); err != nil {
		return err
	}

	if err := initDefaultRole(); err != nil {
		return err
	}

	return nil
}

func updateRoleData() error {
	if err := updateAdmin(); err != nil {
		return err
	}

	return nil
}

func initAdmin() error {
	menuIds := make([]int, 0)
	for _, menu := range MenuInitEntities {
		if menu.MenuID == 0 {
			continue
		}
		menuIds = append(menuIds, menu.MenuID)
	}
	for _, menu := range BusMenuEntities {
		if menu.MenuID == 0 {
			continue
		}
		menuIds = append(menuIds, menu.MenuID)
	}
	admin := model.Role{
		RoleID:    1,
		RoleName:  "超管角色",
		Status:    "1",
		RoleSort:  1,
		Remark:    "超级管理员角色,谨慎操作",
		MenuIds:   menuIds,
		DataScope: "1",
		ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1},
		ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()},
	}
	if err := service.ServicesGroupApp.RoleService.CreateRole(admin); err != nil {
		if err.Error() == code.ErrCodeMap[code.ErrRoleAlreadyExistCode].Error() {
			return nil
		} else {
			return err
		}
	}
	return nil
}

func updateAdmin() error {
	menuIds := make([]int, 0)
	for _, menu := range MenuInitEntities {
		if menu.MenuID == 0 {
			continue
		}
		menuIds = append(menuIds, menu.MenuID)
	}
	for _, menu := range BusMenuEntities {
		if menu.MenuID == 0 {
			continue
		}
		menuIds = append(menuIds, menu.MenuID)
	}
	admin := model.Role{
		RoleID:    1,
		RoleName:  "超管角色",
		Status:    "1",
		RoleSort:  1,
		Remark:    "超级管理员角色,谨慎操作",
		MenuIds:   menuIds,
		DataScope: "1",
		ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1},
		ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()},
	}
	if err := service.ServicesGroupApp.RoleService.UpdateRole(admin); err != nil {
		if err.Error() == code.ErrCodeMap[code.ErrRoleAlreadyExistCode].Error() {
			return nil
		} else {
			return err
		}
	}
	return nil
}

func initDefaultRole() error {
	defaultRole := model.Role{
		RoleID:    2,
		RoleName:  "默认角色",
		Status:    "1",
		RoleSort:  1,
		Remark:    "默认角色仅包含必要权限",
		MenuIds:   nil,
		DataScope: "5",
		ControlBy: common.ControlBy{CreateBy: 1, UpdateBy: 1},
		ModelTime: common.ModelTime{CreatedAt: time.Now(), UpdatedAt: time.Now()},
	}
	if err := service.ServicesGroupApp.RoleService.CreateRole(defaultRole); err != nil {
		if err.Error() == code.ErrCodeMap[code.ErrRoleAlreadyExistCode].Error() {
			return nil
		} else {
			return err
		}
	}
	return nil
}
