package service

import (
	"dy-admin/internal/pcmserver/common"
	"dy-admin/internal/pcmserver/global"
	"dy-admin/internal/pcmserver/pkg/code"
	"dy-admin/internal/pcmserver/sys/model"
	"dy-admin/internal/pcmserver/sys/model/request"
	"dy-admin/pkg/rescode"
	"gorm.io/gorm"
)

type OperationRecordService struct{}

func (operationRecordService *OperationRecordService) CreateSysOperationRecord(sysOperationRecord model.OperationRecord) (err error) {
	err = global.DB.Create(&sysOperationRecord).Error
	if err != nil {
		return rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode])
	}
	return
}

func (operationRecordService *OperationRecordService) DeleteSysOperationRecordByIds(ids []string) (err error) {
	if err = global.DB.Delete(&[]model.OperationRecord{}, "id in (?)", ids).Error; err != nil {
		return rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode])
	}
	return
}

func (operationRecordService *OperationRecordService) DeleteSysOperationRecord(id int) (err error) {
	record := model.OperationRecord{Model: common.Model{ID: id}}
	if err = global.DB.Delete(&record).Error; err != nil {
		return rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode])
	}
	return
}

func (operationRecordService *OperationRecordService) GetSysOperationRecord(id int) (*model.OperationRecord, error) {
	var record model.OperationRecord
	err := global.DB.Where("id = ?", id).First(&record).Error
	if err != nil {
		if err != gorm.ErrRecordNotFound {
			return nil, rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode])
		} else {
			return nil, nil
		}
	}
	return &record, nil
}

func (operationRecordService *OperationRecordService) GetSysOperationRecordInfoList(info request.OperationRecordSearch) (sysOperationRecords []model.OperationRecord, total int64, err error) {
	var limit, offset int
	if info.Page == 0 || info.PageSize == 0 {
		limit = -1
		offset = -1
	} else {
		limit = info.PageSize
		offset = info.PageSize * (info.Page - 1)
	}

	db := global.DB.Model(&model.OperationRecord{})

	if info.Method != "" {
		db = db.Where("method = ?", info.Method)
	}
	if info.Path != "" {
		db = db.Where("path LIKE ?", "%"+info.Path+"%")
	}
	if info.Status != 0 {
		db = db.Where("status = ?", info.Status)
	}
	if info.NickName != "" {
		db = db.Where("nick_name LIKE ?", "%"+info.NickName+"%")
	}
	err = db.Count(&total).Error
	if err != nil {
		return
	}
	if err = db.Order("id desc").Limit(limit).Offset(offset).Find(&sysOperationRecords).Error; err != nil {
		return sysOperationRecords, total, rescode.RegisterErrorWithCause(err, code.ErrCodeMap[code.ErrDatabaseCode])
	}
	return
}
