package rescode

import (
	"dy-admin/pkg/log"
	"dy-admin/pkg/middleware"
	"github.com/gin-gonic/gin"

	"net/http"
)

// Response 用来返回错误消息的结构
type Response struct {
	RequestId string      `json:"requestId,omitempty"`
	Code      string      `json:"code,omitempty"`
	Message   string      `json:"message,omitempty"`
	Reference string      `json:"reference,omitempty"`
	Data      interface{} `json:"data,omitempty"`
}

// WriteErrResponse 解析错误中的错误码等消息，通过gin框架返回
func WriteErrResponse(c *gin.Context, err error) {
	if err != nil {
		errCode := ParseCode(err)
		log.Errorf("%+v", errCode)
		c.JSON(errCode.HTTPStatus(), Response{
			RequestId: middleware.GetRequestIDFromContext(c),
			Code:      errCode.Code(),
			Message:   errCode.Message(),
			Reference: errCode.Reference(),
			Data:      nil,
		})
		return
	}
	WriteSuccessResponse(c, nil)
}

func WriteSuccessResponse(c *gin.Context, data interface{}) {
	res := Response{
		RequestId: middleware.GetRequestIDFromContext(c),
		Code:      successErrCode.Code(),
		Message:   successErrCode.Message(),
		Data:      data,
	}
	c.JSON(http.StatusOK, res)
	return
}
